import { BaseAPIRequestFactory } from './baseapi.js';
import { Configuration } from '../configuration.js';
import { RequestContext, ResponseContext, HttpFile } from '../http/http.js';
import { CreateAnswerRequest } from '../models/CreateAnswerRequest.js';
import { CreateAnswerResponse } from '../models/CreateAnswerResponse.js';
import { CreateClassificationRequest } from '../models/CreateClassificationRequest.js';
import { CreateClassificationResponse } from '../models/CreateClassificationResponse.js';
import { CreateCompletionRequest } from '../models/CreateCompletionRequest.js';
import { CreateCompletionResponse } from '../models/CreateCompletionResponse.js';
import { CreateEditRequest } from '../models/CreateEditRequest.js';
import { CreateEditResponse } from '../models/CreateEditResponse.js';
import { CreateEmbeddingRequest } from '../models/CreateEmbeddingRequest.js';
import { CreateEmbeddingResponse } from '../models/CreateEmbeddingResponse.js';
import { CreateFineTuneRequest } from '../models/CreateFineTuneRequest.js';
import { CreateImageRequest } from '../models/CreateImageRequest.js';
import { CreateModerationRequest } from '../models/CreateModerationRequest.js';
import { CreateModerationResponse } from '../models/CreateModerationResponse.js';
import { CreateSearchRequest } from '../models/CreateSearchRequest.js';
import { CreateSearchResponse } from '../models/CreateSearchResponse.js';
import { DeleteFileResponse } from '../models/DeleteFileResponse.js';
import { DeleteModelResponse } from '../models/DeleteModelResponse.js';
import { Engine } from '../models/Engine.js';
import { FineTune } from '../models/FineTune.js';
import { ImagesResponse } from '../models/ImagesResponse.js';
import { ListEnginesResponse } from '../models/ListEnginesResponse.js';
import { ListFilesResponse } from '../models/ListFilesResponse.js';
import { ListFineTuneEventsResponse } from '../models/ListFineTuneEventsResponse.js';
import { ListFineTunesResponse } from '../models/ListFineTunesResponse.js';
import { ListModelsResponse } from '../models/ListModelsResponse.js';
import { Model } from '../models/Model.js';
import { OpenAIFile } from '../models/OpenAIFile.js';
export declare class OpenAIApiRequestFactory extends BaseAPIRequestFactory {
    cancelFineTune(fineTuneId: string, _options?: Configuration): Promise<RequestContext>;
    createAnswer(createAnswerRequest: CreateAnswerRequest, _options?: Configuration): Promise<RequestContext>;
    createClassification(createClassificationRequest: CreateClassificationRequest, _options?: Configuration): Promise<RequestContext>;
    createCompletion(createCompletionRequest: CreateCompletionRequest, _options?: Configuration): Promise<RequestContext>;
    createEdit(createEditRequest: CreateEditRequest, _options?: Configuration): Promise<RequestContext>;
    createEmbedding(createEmbeddingRequest: CreateEmbeddingRequest, _options?: Configuration): Promise<RequestContext>;
    createFile(file: HttpFile, purpose: string, _options?: Configuration): Promise<RequestContext>;
    createFineTune(createFineTuneRequest: CreateFineTuneRequest, _options?: Configuration): Promise<RequestContext>;
    createImage(createImageRequest: CreateImageRequest, _options?: Configuration): Promise<RequestContext>;
    createImageEdit(image: HttpFile, prompt: string, mask?: HttpFile, n?: number, size?: string, responseFormat?: string, user?: string, _options?: Configuration): Promise<RequestContext>;
    createImageVariation(image: HttpFile, n?: number, size?: string, responseFormat?: string, user?: string, _options?: Configuration): Promise<RequestContext>;
    createModeration(createModerationRequest: CreateModerationRequest, _options?: Configuration): Promise<RequestContext>;
    createSearch(engineId: string, createSearchRequest: CreateSearchRequest, _options?: Configuration): Promise<RequestContext>;
    deleteFile(fileId: string, _options?: Configuration): Promise<RequestContext>;
    deleteModel(model: string, _options?: Configuration): Promise<RequestContext>;
    downloadFile(fileId: string, _options?: Configuration): Promise<RequestContext>;
    listEngines(_options?: Configuration): Promise<RequestContext>;
    listFiles(_options?: Configuration): Promise<RequestContext>;
    listFineTuneEvents(fineTuneId: string, stream?: boolean, _options?: Configuration): Promise<RequestContext>;
    listFineTunes(_options?: Configuration): Promise<RequestContext>;
    listModels(_options?: Configuration): Promise<RequestContext>;
    retrieveEngine(engineId: string, _options?: Configuration): Promise<RequestContext>;
    retrieveFile(fileId: string, _options?: Configuration): Promise<RequestContext>;
    retrieveFineTune(fineTuneId: string, _options?: Configuration): Promise<RequestContext>;
    retrieveModel(model: string, _options?: Configuration): Promise<RequestContext>;
}
export declare class OpenAIApiResponseProcessor {
    cancelFineTune(response: ResponseContext): Promise<FineTune>;
    createAnswer(response: ResponseContext): Promise<CreateAnswerResponse>;
    createClassification(response: ResponseContext): Promise<CreateClassificationResponse>;
    createCompletion(response: ResponseContext): Promise<CreateCompletionResponse>;
    createEdit(response: ResponseContext): Promise<CreateEditResponse>;
    createEmbedding(response: ResponseContext): Promise<CreateEmbeddingResponse>;
    createFile(response: ResponseContext): Promise<OpenAIFile>;
    createFineTune(response: ResponseContext): Promise<FineTune>;
    createImage(response: ResponseContext): Promise<ImagesResponse>;
    createImageEdit(response: ResponseContext): Promise<ImagesResponse>;
    createImageVariation(response: ResponseContext): Promise<ImagesResponse>;
    createModeration(response: ResponseContext): Promise<CreateModerationResponse>;
    createSearch(response: ResponseContext): Promise<CreateSearchResponse>;
    deleteFile(response: ResponseContext): Promise<DeleteFileResponse>;
    deleteModel(response: ResponseContext): Promise<DeleteModelResponse>;
    downloadFile(response: ResponseContext): Promise<string>;
    listEngines(response: ResponseContext): Promise<ListEnginesResponse>;
    listFiles(response: ResponseContext): Promise<ListFilesResponse>;
    listFineTuneEvents(response: ResponseContext): Promise<ListFineTuneEventsResponse>;
    listFineTunes(response: ResponseContext): Promise<ListFineTunesResponse>;
    listModels(response: ResponseContext): Promise<ListModelsResponse>;
    retrieveEngine(response: ResponseContext): Promise<Engine>;
    retrieveFile(response: ResponseContext): Promise<OpenAIFile>;
    retrieveFineTune(response: ResponseContext): Promise<FineTune>;
    retrieveModel(response: ResponseContext): Promise<Model>;
}
