import { HttpFile } from '../http/http.js';
import { Configuration } from '../configuration.js';
import { CreateAnswerRequest } from '../models/CreateAnswerRequest.js';
import { CreateAnswerResponse } from '../models/CreateAnswerResponse.js';
import { CreateClassificationRequest } from '../models/CreateClassificationRequest.js';
import { CreateClassificationResponse } from '../models/CreateClassificationResponse.js';
import { CreateCompletionRequest } from '../models/CreateCompletionRequest.js';
import { CreateCompletionResponse } from '../models/CreateCompletionResponse.js';
import { CreateEditRequest } from '../models/CreateEditRequest.js';
import { CreateEditResponse } from '../models/CreateEditResponse.js';
import { CreateEmbeddingRequest } from '../models/CreateEmbeddingRequest.js';
import { CreateEmbeddingResponse } from '../models/CreateEmbeddingResponse.js';
import { CreateFineTuneRequest } from '../models/CreateFineTuneRequest.js';
import { CreateImageRequest } from '../models/CreateImageRequest.js';
import { CreateModerationRequest } from '../models/CreateModerationRequest.js';
import { CreateModerationResponse } from '../models/CreateModerationResponse.js';
import { CreateSearchRequest } from '../models/CreateSearchRequest.js';
import { CreateSearchResponse } from '../models/CreateSearchResponse.js';
import { DeleteFileResponse } from '../models/DeleteFileResponse.js';
import { DeleteModelResponse } from '../models/DeleteModelResponse.js';
import { Engine } from '../models/Engine.js';
import { FineTune } from '../models/FineTune.js';
import { ImagesResponse } from '../models/ImagesResponse.js';
import { ListEnginesResponse } from '../models/ListEnginesResponse.js';
import { ListFilesResponse } from '../models/ListFilesResponse.js';
import { ListFineTuneEventsResponse } from '../models/ListFineTuneEventsResponse.js';
import { ListFineTunesResponse } from '../models/ListFineTunesResponse.js';
import { ListModelsResponse } from '../models/ListModelsResponse.js';
import { Model } from '../models/Model.js';
import { OpenAIFile } from '../models/OpenAIFile.js';
import { OpenAIApiRequestFactory, OpenAIApiResponseProcessor } from "../apis/OpenAIApi.js";
export interface OpenAIApiCancelFineTuneRequest {
    fineTuneId: string;
}
export interface OpenAIApiCreateAnswerRequest {
    createAnswerRequest: CreateAnswerRequest;
}
export interface OpenAIApiCreateClassificationRequest {
    createClassificationRequest: CreateClassificationRequest;
}
export interface OpenAIApiCreateCompletionRequest {
    createCompletionRequest: CreateCompletionRequest;
}
export interface OpenAIApiCreateEditRequest {
    createEditRequest: CreateEditRequest;
}
export interface OpenAIApiCreateEmbeddingRequest {
    createEmbeddingRequest: CreateEmbeddingRequest;
}
export interface OpenAIApiCreateFileRequest {
    file: HttpFile;
    purpose: string;
}
export interface OpenAIApiCreateFineTuneRequest {
    createFineTuneRequest: CreateFineTuneRequest;
}
export interface OpenAIApiCreateImageRequest {
    createImageRequest: CreateImageRequest;
}
export interface OpenAIApiCreateImageEditRequest {
    image: HttpFile;
    prompt: string;
    mask?: HttpFile;
    n?: number;
    size?: string;
    responseFormat?: string;
    user?: string;
}
export interface OpenAIApiCreateImageVariationRequest {
    image: HttpFile;
    n?: number;
    size?: string;
    responseFormat?: string;
    user?: string;
}
export interface OpenAIApiCreateModerationRequest {
    createModerationRequest: CreateModerationRequest;
}
export interface OpenAIApiCreateSearchRequest {
    engineId: string;
    createSearchRequest: CreateSearchRequest;
}
export interface OpenAIApiDeleteFileRequest {
    fileId: string;
}
export interface OpenAIApiDeleteModelRequest {
    model: string;
}
export interface OpenAIApiDownloadFileRequest {
    fileId: string;
}
export interface OpenAIApiListEnginesRequest {
}
export interface OpenAIApiListFilesRequest {
}
export interface OpenAIApiListFineTuneEventsRequest {
    fineTuneId: string;
    stream?: boolean;
}
export interface OpenAIApiListFineTunesRequest {
}
export interface OpenAIApiListModelsRequest {
}
export interface OpenAIApiRetrieveEngineRequest {
    engineId: string;
}
export interface OpenAIApiRetrieveFileRequest {
    fileId: string;
}
export interface OpenAIApiRetrieveFineTuneRequest {
    fineTuneId: string;
}
export interface OpenAIApiRetrieveModelRequest {
    model: string;
}
export declare class ObjectOpenAIApi {
    private api;
    constructor(configuration: Configuration, requestFactory?: OpenAIApiRequestFactory, responseProcessor?: OpenAIApiResponseProcessor);
    cancelFineTune(param: OpenAIApiCancelFineTuneRequest, options?: Configuration): Promise<FineTune>;
    createAnswer(param: OpenAIApiCreateAnswerRequest, options?: Configuration): Promise<CreateAnswerResponse>;
    createClassification(param: OpenAIApiCreateClassificationRequest, options?: Configuration): Promise<CreateClassificationResponse>;
    createCompletion(param: OpenAIApiCreateCompletionRequest, options?: Configuration): Promise<CreateCompletionResponse>;
    createEdit(param: OpenAIApiCreateEditRequest, options?: Configuration): Promise<CreateEditResponse>;
    createEmbedding(param: OpenAIApiCreateEmbeddingRequest, options?: Configuration): Promise<CreateEmbeddingResponse>;
    createFile(param: OpenAIApiCreateFileRequest, options?: Configuration): Promise<OpenAIFile>;
    createFineTune(param: OpenAIApiCreateFineTuneRequest, options?: Configuration): Promise<FineTune>;
    createImage(param: OpenAIApiCreateImageRequest, options?: Configuration): Promise<ImagesResponse>;
    createImageEdit(param: OpenAIApiCreateImageEditRequest, options?: Configuration): Promise<ImagesResponse>;
    createImageVariation(param: OpenAIApiCreateImageVariationRequest, options?: Configuration): Promise<ImagesResponse>;
    createModeration(param: OpenAIApiCreateModerationRequest, options?: Configuration): Promise<CreateModerationResponse>;
    createSearch(param: OpenAIApiCreateSearchRequest, options?: Configuration): Promise<CreateSearchResponse>;
    deleteFile(param: OpenAIApiDeleteFileRequest, options?: Configuration): Promise<DeleteFileResponse>;
    deleteModel(param: OpenAIApiDeleteModelRequest, options?: Configuration): Promise<DeleteModelResponse>;
    downloadFile(param: OpenAIApiDownloadFileRequest, options?: Configuration): Promise<string>;
    listEngines(param?: OpenAIApiListEnginesRequest, options?: Configuration): Promise<ListEnginesResponse>;
    listFiles(param?: OpenAIApiListFilesRequest, options?: Configuration): Promise<ListFilesResponse>;
    listFineTuneEvents(param: OpenAIApiListFineTuneEventsRequest, options?: Configuration): Promise<ListFineTuneEventsResponse>;
    listFineTunes(param?: OpenAIApiListFineTunesRequest, options?: Configuration): Promise<ListFineTunesResponse>;
    listModels(param?: OpenAIApiListModelsRequest, options?: Configuration): Promise<ListModelsResponse>;
    retrieveEngine(param: OpenAIApiRetrieveEngineRequest, options?: Configuration): Promise<Engine>;
    retrieveFile(param: OpenAIApiRetrieveFileRequest, options?: Configuration): Promise<OpenAIFile>;
    retrieveFineTune(param: OpenAIApiRetrieveFineTuneRequest, options?: Configuration): Promise<FineTune>;
    retrieveModel(param: OpenAIApiRetrieveModelRequest, options?: Configuration): Promise<Model>;
}
